@@ -1,5 +1,5 @@
-import pard.raw_python_dictionaries
-from pard.handling_3_letter_code_decorator import handling_3_letter_code
+import pard._raw_python_dictionaries
+from pard._handling_3_letter_code_decorator import handling_3_letter_code
 
 @handling_3_letter_code
 def epstein(amino_acid_1: str, amino_acid_2: str, symmetric: bool) -> float:
@@ -12,6 +12,6 @@ def epstein(amino_acid_1: str, amino_acid_2: str, symmetric: bool) -> float:
     :return: An integer representing the Miyata distance between amino_acid_1 and amino_acid_2
     """
     if symmetric:
-        return pard.raw_python_dictionaries.SYMMETRIC_EPSTEIN_DICT[(amino_acid_1, amino_acid_2)]
+        return pard._raw_python_dictionaries.SYMMETRIC_EPSTEIN_DICT[(amino_acid_1, amino_acid_2)]
     else:
-        return pard.raw_python_dictionaries.ASYMMETRIC_EPSTEIN_DICT[(amino_acid_1, amino_acid_2)]
+        return pard._raw_python_dictionaries.ASYMMETRIC_EPSTEIN_DICT[(amino_acid_1, amino_acid_2)]
