@@ -1,5 +1,5 @@
-import pard.raw_python_dictionaries
-from pard.handling_3_letter_code_decorator import handling_3_letter_code
+import pard._raw_python_dictionaries
+from pard._handling_3_letter_code_decorator import handling_3_letter_code
 
 @handling_3_letter_code
 def miyata(amino_acid_1: str, amino_acid_2: str) -> float:
@@ -9,4 +9,4 @@ def miyata(amino_acid_1: str, amino_acid_2: str) -> float:
 
     :return: An integer representing the Miyata distance between amino_acid_1 and amino_acid_2
     """
-    return pard.raw_python_dictionaries.MIYATA_DICT[(amino_acid_1, amino_acid_2)]
+    return pard._raw_python_dictionaries.MIYATA_DICT[(amino_acid_1, amino_acid_2)]
